use std::{
	error::Error,
	sync::Arc,
};

use tracing::{info};
use tracing_subscriber::{
	fmt, 
	fmt::format::FmtSpan,
	EnvFilter,
};

use ptth::relay;
use ptth::relay::RelayState;

#[tokio::main]
async fn main () -> Result <(), Box <dyn Error>> {
	fmt ()
		.with_env_filter (EnvFilter::from_default_env ())
		.with_span_events (FmtSpan::FULL)
		.init ()
	;
	
	let config_file = ptth::load_toml::load ("config/ptth_relay.toml");
	
	info! ("ptth_relay Git version: {:?}", ptth::git_version::GIT_VERSION);
	
	relay::run_relay (
		Arc::new (RelayState::from (&config_file)),
		ptth::graceful_shutdown::init ()
	).await
}
